@@ -194,7 +194,6 @@ totem_action_exit (Totem *totem)
 	totem_action_fullscreen (totem, FALSE);
 
 	totem_sublang_exit (totem);
-	totem_destroy_file_filters ();
 	totem_named_icons_dispose (totem);
 
 	if (totem->bvw)
@@ -425,8 +424,8 @@ totem_action_load_media_device (Totem *totem, const char *device)
 
 	switch (type) {
 		case MEDIA_TYPE_ERROR:
-			totem_action_error (_("Failed to play Audio/Video Disc"),
-					    error ? error->message : _("Reason unknown"),
+			totem_action_error (_("Totem was not able to play this disc."),
+					    error ? error->message : _("No reason."),
 					    totem);
 			retval = FALSE;
 			break;
@@ -1229,7 +1228,7 @@ on_got_metadata_event (BaconVideoWidget *bvw, Totem *totem)
 {
         char *name = NULL;
 
-        bacon_video_widget_properties_update
+	bacon_video_widget_properties_update
 		(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
 		 totem->bvw);
 
@@ -1240,17 +1239,8 @@ on_got_metadata_event (BaconVideoWidget *bvw, Totem *totem)
 			(TOTEM_PLAYLIST (totem->playlist), name);
 		g_free (name);
 	} else {
-		GValue v = { 0 };
-		const gchar *cdid;
-
-		bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_CDINDEX, &v);
-		if ((cdid = g_value_get_string (&v)) != NULL) {
-			totem_playlist_set_cdindex
-				(TOTEM_PLAYLIST (totem->playlist), cdid);
-		}
-		on_playlist_change_name
+		on_playlist_change_name 	 
 			(TOTEM_PLAYLIST (totem->playlist), totem);
-		g_value_unset (&v);
 	}
 }
 
@@ -1394,6 +1384,13 @@ seek_slider_pressed_cb (GtkWidget *widget, GdkEventButton *event, Totem *totem)
 {
 	totem->seek_lock = TRUE;
 	totem_statusbar_set_seeking (TOTEM_STATUSBAR (totem->statusbar), TRUE);
+
+	if (bacon_video_widget_can_direct_seek (totem->bvw) != FALSE)
+	{
+		totem->was_playing = bacon_video_widget_is_playing (totem->bvw);
+		bacon_video_widget_pause (totem->bvw);
+	}
+
 	return FALSE;
 }
 
@@ -1405,34 +1402,41 @@ seek_slider_changed_cb (GtkAdjustment *adj, Totem *totem)
 
 	if (totem->seek_lock == FALSE)
 		return;
-  
+
 	pos = gtk_adjustment_get_value (adj) / 65535;
 	time = bacon_video_widget_get_stream_length (totem->bvw);
 	totem_statusbar_set_time_and_length (TOTEM_STATUSBAR (totem->statusbar),
 			(int) (pos * time / 1000), time / 1000);
+
+	if (bacon_video_widget_can_direct_seek (totem->bvw) != FALSE)
+		totem_action_seek (totem, pos);
 }
 
 static gboolean
 seek_slider_released_cb (GtkWidget *widget, GdkEventButton *event, Totem *totem)
 {
-	if (g_object_get_data (G_OBJECT (widget), "fs") != FALSE)
+	GtkAdjustment *adj, *other_adj;
+	gdouble val;
+
+	adj = gtk_range_get_adjustment (GTK_RANGE (widget));
+	other_adj = (adj == totem->seekadj) ? totem->fs_seekadj : totem->seekadj;
+
+	/* set to FALSE here to avoid triggering a final seek when
+	 * syncing the adjustments while being in direct seek mode */
+	totem->seek_lock = FALSE;
+
+	/* sync both adjustments */
+	val = gtk_adjustment_get_value (adj);
+	gtk_adjustment_set_value (other_adj, val);
+
+	if (bacon_video_widget_can_direct_seek (totem->bvw) != FALSE)
 	{
-		totem_action_seek (totem,
-				gtk_adjustment_get_value (totem->fs_seekadj) / 65535);
-		/* Update the fullscreen seek adjustment */
-		gtk_adjustment_set_value (totem->seekadj,
-				gtk_adjustment_get_value
-				(totem->fs_seekadj));
+		if (totem->was_playing)
+			bacon_video_widget_play (totem->bvw, NULL);
 	} else {
-		totem_action_seek (totem,
-				gtk_adjustment_get_value (totem->seekadj) / 65535);
-		/* Update the seek adjustment */
-		gtk_adjustment_set_value (totem->fs_seekadj,
-				gtk_adjustment_get_value
-				(totem->seekadj));
+		totem_action_seek (totem, val / 65535.0);
 	}
 
-	totem->seek_lock = FALSE;
 	totem_statusbar_set_seeking (TOTEM_STATUSBAR (totem->statusbar), FALSE);
 	return FALSE;
 }
@@ -3098,6 +3102,8 @@ totem_callback_connect (Totem *totem)
 			G_CALLBACK (seek_slider_pressed_cb), totem);
 	g_signal_connect (G_OBJECT(totem->fs_seek), "button_release_event",
 			G_CALLBACK (seek_slider_released_cb), totem);
+	g_signal_connect (G_OBJECT (totem->fs_seekadj), "value-changed",
+			  G_CALLBACK (seek_slider_changed_cb), totem);
 	g_signal_connect (G_OBJECT(totem->fs_volume), "value-changed",
 			G_CALLBACK (vol_cb), totem);
 	g_signal_connect (G_OBJECT(totem->fs_volume), "button_press_event",
